=======
Credits
=======

Authors and Maintainers
---------------------

* Isabella Hochschild <https://github.com/isabellahoch>
* Elizabeth Frey <https://github.com/lizwfrey>

Contributors
------------

None yet. Why not be the first?
